import { CommonModule } from '@angular/common';
import { Component, OnInit, ViewChild, ElementRef, OnDestroy } from '@angular/core';
import { FormsModule } from '@angular/forms';

import * as wjcCore from '@mescius/wijmo';
import { WjGridModule } from '@mescius/wijmo.angular2.grid';
import { FlexGridFilter, } from '@mescius/wijmo.grid.filter';
import { WjGridFilterModule } from '@mescius/wijmo.angular2.grid.filter';
import * as wjGrid from '@mescius/wijmo.grid';

@Component({
  selector: 'app-grid',
  standalone: true,
  imports: [WjGridModule, WjGridFilterModule, FormsModule, CommonModule],
  templateUrl: './grid.component.html',
  styleUrls: ['./grid.component.css']
})
export class GridComponent implements OnInit, OnDestroy {

  @ViewChild('flexGrid') flexGrid?: wjGrid.FlexGrid;

  gridData = this.getData();
  columns = [
    { binding: 'id', header: 'ID', width: 150 },
    { binding: 'country', header: 'Country', width: 150 },
    { binding: 'sales', header: 'Sales', width: 150 },
  ]

  onGridInitialized(flexGrid: any) {
    console.log('flex init');
    //
  }

  initFilter(filter: FlexGridFilter) {
    console.log('filter init');

    let filterDef = '{"defaultFilterType":3,"filters":[{"binding":"country","type":"value","uniqueValues":null,"sortValues":true,"maxValues":250,"exclusiveValueSearch":true,"showValues":{"Germany":true}}]}';
    filter.filterDefinition = filterDef;
  }

  filterChanged(filter: FlexGridFilter, e: wjGrid.CellRangeEventArgs) {
    console.log('filter changed');
  }

  getData() {
    // create some random data
    let countries = 'US,Germany,UK,Japan,Italy,Greece'.split(','),
      data = [];
    for (let i = 0; i < countries.length; i++) {
      data.push({
        id: i,
        country: countries[i],
        sales: Math.random() * 10000,
        expenses: Math.random() * 5000
      });
    }
    return data;
  }

  ngOnInit() {
  }

  ngOnDestroy() {
    console.log('destroyed');
  }

}
